pub struct AvailableFeatures {
pub rtc: bool,
pub transcription: bool,
pub audio_recording: bool,
pub video_recording: bool,
}Expand description
room capabilities advertised to a newly connected browser client
these are call capabilities, not permission checks the room advertises which features exist for the call, then per-user permissions decide who may actually start or change a restricted feature
Fields
rtc: boolfalse keeps compatibility with websocket-relay rooms
transcription: boolaudio_recording: boolvideo_recording: boolTrait Implementations
Sourceimpl Clone for AvailableFeatures
impl Clone for AvailableFeatures
Sourcefn clone(&self) -> AvailableFeatures
fn clone(&self) -> AvailableFeatures
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AvailableFeatures
impl Debug for AvailableFeatures
Sourceimpl<'de> Deserialize<'de> for AvailableFeatures
impl<'de> Deserialize<'de> for AvailableFeatures
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<AvailableFeatures, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<AvailableFeatures, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for AvailableFeatures
impl PartialEq for AvailableFeatures
Sourceimpl Serialize for AvailableFeatures
impl Serialize for AvailableFeatures
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Eq for AvailableFeatures
impl StructuralPartialEq for AvailableFeatures